@@ -32,6 +32,7 @@
   #:use-module (oop goops)
   
   #:use-module (g-wrap)
+  #:use-module (g-wrap c-codegen)
   #:use-module (g-wrap rti)
   #:use-module (g-wrap util)
 
@@ -49,7 +50,7 @@
 
 (define (val-array-cg enum)
   (list
-   "static GWEnumPair " (slot-ref enum 'val-array-name) "[] = {\n"
+   "static const GWEnumPair " (slot-ref enum 'val-array-name) "[] = {\n"
    (map
     (lambda (enum-val)
       (let ((c-sym (cdr enum-val))
