@@ -39,9 +39,9 @@ struct _GWEnumPair
 };
 
 void gw_guile_runtime_init (void);
-SCM gw_guile_enum_val2sym(GWEnumPair enum_pairs[], SCM scm_val,
+SCM gw_guile_enum_val2sym(const GWEnumPair enum_pairs[], SCM scm_val,
                           SCM scm_show_all_p);
-SCM gw_guile_enum_val2int(GWEnumPair enum_pairs[], SCM scm_val);
+SCM gw_guile_enum_val2int(const GWEnumPair enum_pairs[], SCM scm_val);
 
 void gw_guile_set_generics_module_x (SCM module);
 void gw_guile_make_latent_variable (SCM sym, SCM proc, SCM arg);
