@@ -1,5 +1,5 @@
 ;;;; File: guile.scm
-;;;; Copyright (C) 2004-2007, 2010 Andreas Rottmann
+;;;; Copyright (C) 2004-2007, 2010, 2011 Andreas Rottmann
 ;;;;
 ;;;; based upon G-Wrap 1.3.4,
 ;;;;   Copyright (C) 1996, 1997,1998 Christopher Lee
@@ -57,15 +57,6 @@
 ;;; Utilities
 ;;;
 
-(define (guile-module-name->c-registration-strlist name-symlist)
-  (separate-by (map symbol->string name-symlist) " "))
-
-(define (guile-module-name->c-sym-name-strlist name-symlist)
-  (separate-by
-   (map (lambda (s) (gw:any-str->c-sym-str (symbol->string s)))
-	name-symlist)
-   "_"))
-
 (define-method (scm-var (value <gw-value>))
   (string-append "*(SCM *)" (wrapped-var value)))
 
@@ -114,16 +105,6 @@
 (define-method (initializations-cg (wrapset <gw-guile-wrapset>) err)
   (list
    "gw_guile_runtime_init ();\n"
-   (let ((modules (fold (lambda (ws clauses)
-			  (if (module ws)
-			      (cons (module ws) clauses)
-			      clauses))
-			'()
-			(wrapsets-depended-on wrapset))))
-     (if (null? modules)
-	 '()
-	 (inline-scheme wrapset `(use-modules ,@modules))))
-
    (next-method)))
 
 (define-method (initialize (wrapset <gw-guile-wrapset>) initargs)
@@ -320,17 +301,6 @@
      "  SCM gw__scm_result = SCM_UNSPECIFIED;\n"
      "  GWError gw__error = { GW_ERR_NONE, NULL, NULL };\n"
      "  unsigned int gw__arg_pos = 0;\n"
-     (if (zero? nargs)
-	 '()
-	 (list
-	  "  const GWTypeSpec *typespec = NULL;\n"
-	  "  static const GWTypeSpec typespecs[] = { "
-          (string-join
-           (map (lambda (param)
-                  (typespec-cg (type param) (typespec param)))
-                scm-params)
-           ", ") " };\n"))
-
      (if (needs-result-var? return-type)
          (let ((c-value (default-c-value-for-type return-type)))
            (list
@@ -384,7 +354,6 @@
 				  "gw__scm_deps = scm_cons ("
 				  (scm-var param) ", gw__scm_deps);\n")
 		   "")
-	       "typespec = &typespecs[gw__arg_pos];\n"
 	       "gw__arg_pos++;\n"
 	       (if (>= (number param) *max-fixed-params*)
 		   (list
@@ -864,7 +833,9 @@
   (let* ((wrapset-name (name wrapset))
 	 (wrapset-name-c-sym (any-str->c-sym-str
 			      (symbol->string wrapset-name)))
-	 (guile-module (module wrapset)))
+	 (guile-module (module wrapset))
+         (module-dependencies
+          (filter-map module (wrapsets-depended-on wrapset))))
 
     (flatten-display
      (list
@@ -872,20 +843,28 @@
       "\n"
       (format #f "(define-module ~S\n" guile-module)
       (format #f "  #:use-module (g-wrap config)\n")
+      (map (lambda (m) (format #f "  #:use-module ~s\n" m))
+           module-dependencies)
       ")\n"
       "\n"
-      (if (slot-ref wrapset 'shlib-abs?)
-          (list "(dynamic-call \"gw_init_wrapset_" wrapset-name-c-sym "\"\n"
-                "              (dynamic-link (string-append *g-wrap-shlib-dir* \""
-                (slot-ref wrapset 'shlib-path) "\")))\n")
-          (list "(dynamic-call \"gw_init_wrapset_" wrapset-name-c-sym "\"\n"
-                "              (dynamic-link \"" (slot-ref wrapset 'shlib-path) "\"))\n"))
+      (let ((load-extension
+             (list
+              "(load-extension "
+              (if (slot-ref wrapset 'shlib-abs?)
+                  (list "(string-append *g-wrap-shlib-dir* \""
+                        (slot-ref wrapset 'shlib-path) "\") ")
+                  (list "\"" (slot-ref wrapset 'shlib-path) "\" "))
+              "\"gw_init_wrapset_" wrapset-name-c-sym "\")")))
+        (list
+         "(cond-expand\n"
+         "  (guile-2\n"
+         "    (eval-when (eval load compile) " load-extension "))\n"
+         "  (else\n"
+         "    " load-extension "))\n"))
       "(export " (map (lambda (sym)
 			(list "    " sym "\n"))
 		      (module-exports wrapset))
-      ")"
-;;      "(module-use! (module-public-interface (current-module)) (current-module))\n"
-      )
+      ")")
      port)
     (let ((gf-hash       (make-hash-table 67))
           (has-generics? #f))
@@ -934,13 +913,13 @@
           funcs)
          (newline port))
        #f gf-hash)
-      (write
-       '(if (defined? '%generics)
-            (begin
-              (module-use! (module-public-interface (current-module))
-                           %generics)))
-       port)
-      (newline port))))
+
+      (cond (has-generics?
+             (write
+              '(module-use! (module-public-interface (current-module))
+                            %generics)
+              port)
+             (newline port))))))
 
 (define (make-header-def-sym filename)
   (string-append "__"
